# mkrundir

Create an `XDG_RUNTIME_DIR` in `/run/`.

This is a privileged helper that creates a runtime directory for the current
user. The directory is created in `/run/user-$UID`. `/run` should be mounted as
`tmpfs`.

## Design notes

- Must be explicitly called by the user (e.g.: via `~/.profile`).
- Doesn't require PAM (but doesn't conflict with it either).
- On Linux, relies on capabilities(7) for privilege escalation.
- Might have issues inside containers, due to privilege escalation.
- Deleting the directory on logout is out of scope (more on this below).

## Security considerations

Ideally, the `mkrundir` binary should be installed setuid with permissions
`750`, and owned by `root:seat`. Users allowed to use `mkrundir` must be
members of the `seat` group (or another group of your choosing).

## Requirements

- [hare](https://harelang.org) (build)
- make (optional)
- libcap-setcap (or some other mechanism to set capabilities).

## Build

    make all

## Installation

For `doas` users:

    doas make install

For `sudo` users:

    sudo make install

## Setup

When using `zsh`, add the following at the top of `~/.zprofile`:

    export XDG_RUNTIME_DIR=$(mkrundir)

## Specification

The `XDG_RUNTIME_DIR` and its requirements are defined in the [XDG Base
Directory Specification][xdg-basedir].

[xdg-basedir]: https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html

The specification requires that the directory be created upon user login.
`mkrundir` must be executed via `.profile` or a similar mechanism early during
session start-up (notably, before services like a Wayland compositor or the
D-Bus server).

The specification also requires that the directory be deleted after a user's
last session ends. It is up to the system administrator to devise and implement
a mechanism that enforces this. Removal of the directory is out of scope for
this tool.

Failing to remove the directory will result in a small memory usage after the
user has logged out (due to the usage of `tmpfs`). Keep in mind that deleting
this may interfere with potential lingering processes from the logged-out user.

## See also

The following tools also implement creation of this directory:

- https://github.com/jjk-jacky/pam_rundir/
- https://github.com/systemd/systemd/
- https://github.com/elogind/elogind

## Licence

This project is licensed under the ISC licence. See LICENCE for details.
